import { z } from "zod";

import * as GP from "../globalProperties";
import * as M from "../messages";
import * as R from "../regex";

const checkoutObjVal = {
  name: z
    .string({ required_error: M.requiredMessage })
    .regex(R.justOneWord, M.nameMessage),
  surname: z
    .string({ required_error: M.requiredMessage })
    .regex(R.justOneWord, M.nameMessage),
  address: z.string({ required_error: M.requiredMessage }),
  postalCode: GP.postalCode,
  city: z
    .string({ required_error: M.requiredMessage })
    .min(2, M.onlyMinimumTwoCharacters)
    .regex(R.justLetters, M.onlyTextMessage),
  province: z.string({ required_error: M.requiredMessage }),
  phone: z.string({ required_error: M.requiredMessage }).refine((val) => {
    return val.length > 0;
  }, M.requiredMessage),
  senderName: z.string().regex(R.justLetters),
  senderCifNif: z
    .string()
    .regex(R.justLettersAndNumbers, M.onlyTextAndNumbersMessage),
  senderEmail: z.string().email(M.emailMessage),
  senderPhone: z.string().refine((val) => {
    return val.length >= 0;
  }, M.phoneMessage),
  senderNotes: z.string(),
  paymentMethod: z.enum(["redsys", "paypal"], {
    required_error: "Seleccione uno de los métodos de pago!",
  }),
  terms: z.boolean().refine((val) => {
    return val === true;
  }, "Acepte las condiciones antes de continuar con la compra"),
};

export const checkoutSchema = z.object(checkoutObjVal).partial({
  senderName: true,
  senderCifNif: true,
  senderEmail: true,
  senderPhone: true,
  senderNotes: true,
});
